##  Mapping Relations Between the Assets
If you use the "groups" relation between your assets, you have the option to reflect it as many-to-many relations in data object fact sheets. For instance, you can map it to the requires/required by relation in SAP LeanIX.
In the Relation Mapping list, select the mapping option that you need.
The following image illustrates how relations between assets are mapped when the requiresRelation / relToRequiredByRelation option is selected.
![Relations Between Assets Mapped to Requires/Required by Relation](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2745ed627a441014b50dfa1af2b28a7f_LowRes.png)
Relations Between Assets Mapped to Requires/Required by Relation
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
